---
title: No-Code CLI User Guide
---

## About

This is the complete guide to using the command-line interface (CLI) to Planet’s
APIs. It’s divided up into a number of sections, so you can jump right into 
the examples for an API you’re interested in. If you’re new to CLI’s it should
provide all the information you need to work more directly with Planet’s API’s.

## CLI Guide Overview

* **[CLI Introduction](cli-intro.md)** provides an introduction to using a
CLI and highlights some of the key concepts and tools that work with Planet’s CLI.
If you’re already comfortable with CLI tools you can safely skip this section.
* **[CLI for Data API](cli-data.md)** explores the `planet data` commands with 
extensive examples.
* **[CLI for Orders API](cli-orders.md)** dives into the `planet orders` commands
with numerous samples to get you started.
* **[CLI for Subscriptions API](cli-subscriptions.md)** - explains the `planet subscriptions` commands
* **[CLI Tips & Tricks](cli-tips-tricks.md)** highlights a number of interesting 
geospatial CLI command-line tools and shows you how to use them in conjunction
with Planet’s tools.

## CLI Set-up

Getting your CLI set up with your Planet account is covered in the 
[Quick Start Guide](../get-started/quick-start-guide.md), so be sure
to do that before going into any of the next sections.
